@@ -42,4 +42,4 @@ class ScpiSerialTransport(ScpiTransportBase):
         port.timeout = 0
         while port.read() != b'':
             pass
-        port.timeout = 5
+        port.timeout = timeout
